(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7344,        207]
NotebookOptionsPosition[      6824,        187]
NotebookOutlinePosition[      7161,        202]
CellTagsIndexPosition[      7118,        199]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"The", " ", "Bolzano"}], "-", 
   RowBox[{
   "Weierstrass", " ", "function", " ", "was", " ", "the", " ", "first", " ", 
    "function", " ", "which", " ", "could", " ", "be", " ", "proved", " ", 
    "to", " ", "be", " ", "everywhere", " ", "continuous", " ", "and", " ", 
    "nowhere", " ", 
    RowBox[{"differentiable", ".", " ", "Such"}], " ", "functions", " ", 
    "are", " ", 
    RowBox[{"generic", ".", " ", "Brownian"}], " ", "motion", " ", "and", " ",
     "quantum", " ", "mechanics", " ", "involves", " ", "such", " ", 
    RowBox[{"functions", "."}]}]}]}]], "Input",
 Editable->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460870431992602*^9, 3.460870453760314*^9}, {
   3.460870552862218*^9, 3.460870636077525*^9}, 3.460870685964413*^9},
 FontSize->18,
 Background->RGBColor[0.5, 0, 0.5]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
     "The", " ", "Bolzano", " ", "Weierstrass", " ", "function", " ", "is", 
      " ", "defined", " ", "for", " ", "a", " ", "in", " ", "the", " ", 
      "range", " ", 
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}], " ", "and", " ", "b", " ", "an", " ", 
      "odd", " ", 
      RowBox[{"integer", ".", " ", "It"}], " ", "is", " ", "everywhere", " ", 
      "continuous", " ", "but", " ", "nowhere", " ", "differentiable", " ", 
      "if", " ", "ab"}], " ", ">", " ", "1."}], "\[IndentingNewLine]", "*)"}],
   
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"BolzanoWeierstrass", "[", 
     RowBox[{"x_", ",", "a_", ",", "b_", ",", "max_"}], "]"}], " ", ":=", " ",
     
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "^", "n"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"Pi", " ", 
         RowBox[{"b", "^", "n"}], " ", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "max"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"BolzanoWeierstrass", "[", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"1", "/", "5"}], "+", 
          RowBox[{"1", "/", "20"}]}], ",", "5", ",", "15"}], "]"}], ",", 
       RowBox[{"BolzanoWeierstrass", "[", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"1", "/", "5"}], "+", 
          RowBox[{"1", "/", "20"}]}], ",", "5", ",", "30"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "/", "5"}], ",", 
       RowBox[{"2", "/", "5"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Pink", ",", "Black"}], "}"}]}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460867437193926*^9, 3.460867753315685*^9}, {
   3.460869631073532*^9, 3.460869645617324*^9}, {3.460869906975198*^9, 
   3.460870027119078*^9}, {3.460870153060638*^9, 3.460870205678112*^9}, {
   3.460870269094981*^9, 3.460870272230266*^9}, {3.460870325905097*^9, 
   3.46087036457954*^9}, {3.460870457669989*^9, 3.460870542599302*^9}, 
   3.460870685964531*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", "\[IndentingNewLine]", "  ", 
    RowBox[{
     RowBox[{
     "The", " ", "formal", " ", "derivative", " ", "of", " ", "the", " ", 
      "Bolzano", " ", "Weierstrass", " ", "function", " ", "in", " ", "terms",
       " ", "of", " ", "the", " ", 
      RowBox[{"series", ".", " ", "The"}], " ", "sum", " ", "does", " ", 
      "not", " ", "congverge", " ", "if", " ", "ab"}], " ", ">", " ", "1."}], 
    "\[IndentingNewLine]", " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DBolzanoWeierstrass", "[", 
     RowBox[{"x_", ",", "a_", ",", "b_", ",", "max_"}], "]"}], " ", ":=", " ",
     
    RowBox[{
     RowBox[{"-", "Pi"}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", " ", "b"}], ")"}], "^", "n"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"Pi", " ", 
          RowBox[{"b", "^", "n"}], " ", "x"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "max"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"DBolzanoWeierstrass", "[", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"1", "/", "5"}], "+", 
        RowBox[{"1", "/", "20"}]}], ",", "5", ",", "100"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "/", "5"}], ",", 
       RowBox[{"2", "/", "5"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"DBolzanoWeierstrass", "[", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"1", "/", "5"}], "+", 
        RowBox[{"1", "/", "20"}]}], ",", "5", ",", "50"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "/", "5"}], ",", 
       RowBox[{"2", "/", "5"}]}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Orange", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"DBolzanoWeierstrass", "[", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"1", "/", "5"}], "+", 
        RowBox[{"1", "/", "20"}]}], ",", "5", ",", "25"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "/", "5"}], ",", 
       RowBox[{"2", "/", "5"}]}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Pink", "}"}]}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460867789345195*^9, 3.460867942620376*^9}, {
   3.460869652745788*^9, 3.460869863912034*^9}, {3.460870043056854*^9, 
   3.460870100316485*^9}, {3.460870133478126*^9, 3.460870136907465*^9}, {
   3.460870217275335*^9, 3.46087023147331*^9}, {3.460870281272287*^9, 
   3.460870307452177*^9}, {3.460870374393819*^9, 3.46087038820898*^9}, 
   3.460870685964627*^9}]
}, Closed]]
},
WindowSize->{640, 573},
WindowMargins->{{150, Automatic}, {Automatic, 52}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (February 7, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 918, 19, 266, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1511, 44, 2346, 60, 253, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3860, 106, 2948, 78, 275, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]]
}
]
*)

(* End of internal cache information *)

