(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     28709,        842]
NotebookOptionsPosition[     27600,        809]
NotebookOutlinePosition[     27958,        825]
CellTagsIndexPosition[     27915,        822]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", " ", 
   RowBox[{
   "Lagrange", " ", "interpolation", " ", "is", " ", "implemented", " ", "in",
     " ", "Mathematica", " ", "through", " ", "the", " ", "functions", " ", 
    "InterpolatingPolynomial", " ", "and", " ", 
    RowBox[{"Interpolation", ".", " ", "Here"}], " ", "we", " ", 
    "demonstrate", " ", "its", " ", "use", " ", "on", " ", "various", " ", 
    "different", " ", "kinds", " ", "of", " ", 
    RowBox[{"functions", "."}]}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",
 Editable->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460885487832235*^9, 3.46088556804148*^9}, 
   3.460886323621348*^9, 3.460959346340382*^9},
 FontSize->18,
 Background->RGBColor[0.5, 0, 0.5]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Set", " ", "up", " ", "the", " ", "knot", " ", "points"}], " ", 
    "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"max", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{"Sort", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Random", "[", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "max"}], "}"}]}], "]"}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460886153956827*^9, 3.460886162453468*^9}, 
   3.460886323621466*^9, 3.460959346340494*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"A", " ", "simple", " ", "polynomial", " ", "function"}], " ", 
    "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"1", "-", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "/", "5"}], " ", "-", "x"}], ")"}]}]}], ")"}]}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"What", " ", "does", " ", "this", " ", "construction", " ", 
     RowBox[{"do", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"InterpolatingPolynomial", "[", 
        RowBox[{"p", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Interpolation", "[", 
         RowBox[{"p", ",", " ", 
          RowBox[{"InterpolationOrder", "\[Rule]", "2"}]}], "]"}], "[", "t", 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Dashed", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"p", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Orange", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"t", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"t", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}]}], ",", 
       
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Pink", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{"Show", "[", 
    RowBox[{"d", ",", "a", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460883935277195*^9, 3.460884257317718*^9}, {
   3.460884804158498*^9, 3.460884922700974*^9}, {3.460885025316354*^9, 
   3.460885096977677*^9}, {3.460885334718207*^9, 3.46088534867458*^9}, {
   3.460886178442006*^9, 3.460886187190572*^9}, 3.460886323621555*^9, 
   3.460959346340581*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "A", " ", "polynomial", " ", "with", " ", "an", " ", "added", " ", 
     "logarithmic", " ", "term"}], " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"1", "-", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "/", "5"}], " ", "-", "x"}], ")"}]}]}], ")"}]}], " ",
       "+", " ", 
      RowBox[{"5", " ", 
       RowBox[{"Log", "[", "x", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"InterpolatingPolynomial", "[", 
        RowBox[{"p", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Interpolation", "[", "p", "]"}], "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Dashed", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"p", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Orange", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"t", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"t", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"5", " ", 
         RowBox[{"Log", "[", "t", "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Pink", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{"Show", "[", 
    RowBox[{"d", ",", "a", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460884401648289*^9, 3.460884406986062*^9}, 
   3.46088444778739*^9, 3.460884935727114*^9, {3.460885111502433*^9, 
   3.460885117440852*^9}, {3.460885303558676*^9, 3.460885328173215*^9}, {
   3.460886194537914*^9, 3.460886213703968*^9}, 3.460886323621653*^9, {
   3.46095853646831*^9, 3.460958544301181*^9}, 3.460959346340677*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"A", " ", "closer", " ", "look", " ", "at", " ", "errors"}], " ", 
    "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"InterpolatingPolynomial", "[", 
            RowBox[{"p", ",", "t"}], "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", 
                RowBox[{"t", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"5", " ", 
              RowBox[{"Log", "[", "t", "]"}]}]}], ")"}]}], "-", "1"}], ",", 
         "\"\<InterpolatingPolynomial\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Interpolation", "[", 
             RowBox[{"p", ",", " ", 
              RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", 
            "t", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", 
                RowBox[{"t", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"5", " ", 
              RowBox[{"Log", "[", "t", "]"}]}]}], ")"}]}], "-", "1"}], ",", 
         "\"\<O[3]\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Interpolation", "[", 
             RowBox[{"p", ",", " ", 
              RowBox[{"InterpolationOrder", "\[Rule]", "2"}]}], "]"}], "[", 
            "t", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", 
                RowBox[{"t", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"5", " ", 
              RowBox[{"Log", "[", "t", "]"}]}]}], ")"}]}], "-", "1"}], ",", 
         RowBox[{"O", "[", "2", "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Blue"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "500"}], ",", 
          RowBox[{"1", "/", "500"}]}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<Fractional error\>\""}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.46095800554418*^9, 3.460958306056081*^9}, {
  3.460958342260075*^9, 3.460958362632171*^9}, {3.460958412809879*^9, 
  3.460958503711879*^9}, {3.460958552846885*^9, 3.460958562525235*^9}, {
  3.460958713393846*^9, 3.460958715273057*^9}, {3.46095897882001*^9, 
  3.460959130636861*^9}, {3.460959292134669*^9, 3.460959293350836*^9}, {
  3.460959334351083*^9, 3.460959346340763*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "A", " ", "function", " ", "with", " ", "a", " ", "simple", " ", "pole"}],
     " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"1", "-", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "/", "5"}], " ", "-", "x"}], ")"}]}]}], ")"}]}], " ",
       "+", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"InterpolatingPolynomial", "[", 
        RowBox[{"p", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Interpolation", "[", "p", "]"}], "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Dashed", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"p", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Orange", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"t", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"t", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"1", "-", "t"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Pink", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{"Show", "[", 
    RowBox[{"d", ",", "a", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460884425317457*^9, 3.460884440530096*^9}, 
   3.460885006858822*^9, {3.460885146407565*^9, 3.460885157567208*^9}, {
   3.460885375813342*^9, 3.460885401498783*^9}, {3.460886231868827*^9, 
   3.460886246051788*^9}, {3.46088632362174*^9, 3.460886394124277*^9}, 
   3.460959346340871*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"A", " ", "closer", " ", "look", " ", "at", " ", "errors"}], " ", 
    "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"InterpolatingPolynomial", "[", 
            RowBox[{"p", ",", "t"}], "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", 
                RowBox[{"t", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "t"}], ")"}]}]}], ")"}]}], "-", "1"}], ",", 
         "\"\<InterpolatingPolynomial\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Interpolation", "[", 
             RowBox[{"p", ",", " ", 
              RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", 
            "t", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", 
                RowBox[{"t", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "t"}], ")"}]}]}], ")"}]}], "-", "1"}], ",", 
         "\"\<O[3]\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Interpolation", "[", 
             RowBox[{"p", ",", " ", 
              RowBox[{"InterpolationOrder", "\[Rule]", "2"}]}], "]"}], "[", 
            "t", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", 
                RowBox[{"t", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "5"}], "-", "t"}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "t"}], ")"}]}]}], ")"}]}], "-", "1"}], ",", 
         "\"\<O[2]\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Blue"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"PlotRange", " ", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "50"}], ",", 
          RowBox[{"1", "/", "500"}]}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<Fractional error\>\""}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460958650000477*^9, 3.4609589176588*^9}, {
   3.46095915722363*^9, 3.460959215354414*^9}, {3.460959249136244*^9, 
   3.460959304274083*^9}, 3.460959346340958*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"A", " ", "random", " ", "function"}], " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Random", "[", "]"}]}], " ", "-", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "max"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"InterpolatingPolynomial", "[", 
        RowBox[{"p", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Interpolation", "[", 
         RowBox[{"p", ",", " ", 
          RowBox[{"InterpolationOrder", "\[Rule]", " ", "2"}]}], "]"}], "[", 
        "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Dashed", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Interpolation", "[", 
         RowBox[{"p", ",", " ", 
          RowBox[{"InterpolationOrder", "\[Rule]", " ", "4"}]}], "]"}], "[", 
        "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Dashed", ",", "Blue"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"p", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Orange", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"a", ",", "b", ",", "d", ",", "c"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.460886323621824*^9, {3.460886412824139*^9, 3.460886412939258*^9}, 
   3.460959346341046*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"The", " ", "Bolzano"}], "-", 
     RowBox[{"Weierstrass", " ", 
      RowBox[{"function", ".", " ", "In"}], " ", "the", " ", "range", " ", 
      "of", " ", "parameters", " ", "used", " ", "the", " ", "function", " ", 
      "is", " ", "regular"}]}], " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"BolzanoWeierstrass", "[", 
     RowBox[{"x_", ",", "a_", ",", "b_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "^", "n"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"Pi", " ", 
         RowBox[{"b", "^", "n"}], " ", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "25"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"max", "=", "30"}], ";", " ", 
    RowBox[{"x", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Random", "[", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "max"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"BolzanoWeierstrass", "[", 
      RowBox[{"x", ",", 
       RowBox[{"1", "/", "5"}], ",", "3"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"What", " ", "does", " ", "this", " ", "construction", " ", 
     RowBox[{"do", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"InterpolatingPolynomial", "[", 
        RowBox[{"p", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Red"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Interpolation", "[", "p", "]"}], "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Dashed", ",", "Black"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"p", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Orange", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"BolzanoWeierstrass", "[", 
        RowBox[{"t", ",", 
         RowBox[{"1", "/", "5"}], ",", "3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Pink", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{"Show", "[", 
    RowBox[{"d", ",", "a", ",", "b", ",", "c", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "3"}], ",", 
          RowBox[{"1", "/", "3"}]}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"d", ",", "b", ",", "c", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "3"}], ",", 
          RowBox[{"1", "/", "3"}]}], "}"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.460885603937119*^9, 3.460885821987463*^9}, {
   3.460885861335271*^9, 3.460886092429217*^9}, {3.460886271962372*^9, 
   3.460886284523705*^9}, 3.46088632362191*^9, 3.460959346341139*^9}]
}, Closed]]
},
WindowSize->{640, 573},
WindowMargins->{{139, Automatic}, {Automatic, 38}},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (February 7, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 813, 17, 296, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1406, 42, 703, 21, 77, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2112, 65, 3129, 90, 231, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[5244, 157, 3132, 89, 253, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[8379, 248, 4530, 126, 451, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[12912, 376, 3112, 91, 253, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[16027, 469, 4391, 126, 451, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[20421, 597, 2934, 87, 275, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[23358, 686, 4226, 120, 363, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]]
}
]
*)

(* End of internal cache information *)
